%define major		53
%define libname 	%mklibname icu %{major}
%define develname 	%mklibname icu -d

%define dataname	%{name}%{major}-data

%define tarballver	%(echo %version|sed -e 's|\\.|_|g')

Summary:	International Components for Unicode
Name:		icu
Version:	53.1
%define subrel	2
Release:	%mkrel 12
Epoch:		1
License:	MIT
Group:		System/Libraries
URL:		http://www.icu-project.org/index.html
Source0:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-src.tgz
Source1:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-docs.zip
Patch0:		icu-50.1-disable-renaming.patch
Patch6:		icu-4.6.1-do-not-promote-ldflags.patch
Patch7:		icu-53.1-CVE-2014-7923-CVE-2014-7926.patch
Patch8:		icu-53.1-regex2.patch
Patch9:		icu-CVE-2014-6585-CVE-2014-6591.patch
Patch10:	icu-55-CVE-2014-8146.patch
Patch11:	icu-55-CVE-2014-8147.patch
Patch12:	icu-55-uresbund-integer-overflow.patch
# fix CVE-2015-1270, patch from chromium 44
Patch13:	ucnv_name.patch
Patch14:	icu-52.1-CVE-2015-4760.patch
BuildRequires:	doxygen
Requires:	%{libname} = %{epoch}:%{version}

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and
    rule based

%package -n %{dataname}
Summary:	Shared data for the International Components for Unicode
Group:		System/Libraries
BuildArch:	noarch
Conflicts:	icu-devel < 1:50.1-3

%description -n %{dataname}
Shared data for the International Components for Unicode.

%package doc
Summary:	Documentation for the International Components for Unicode
Group:		System/Libraries
Requires:	%{name}
BuildArch:	noarch

%description doc
Documentation for the International Components for Unicode.

%package -n %{libname}
Summary:	Libraries for the International Components for Unicode
Group:		System/Libraries
Requires:	%{dataname} = %{epoch}:%{version}-%{release}

%description -n %{libname}
Libraries for the International Components for Unicode.

%package -n %{develname}
Summary:	Development files for the International Components for Unicode
Group:		Development/Other
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Provides:	%{name}%{major}-devel = %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lib%{name}-devel = %{epoch}:%{version}-%{release}
Obsoletes:	%mklibname -d icu 36
Obsoletes:	%mklibname -d icu 34

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%prep
%setup -q -n %{name}
%patch0 -p1 -b .renaming
#patch6 -p0 -b .ldflags
%patch7 -p1 -b .regex-cves
%patch8 -p1 -b .regex2
%patch9 -p0 -b .CVE-2014-6585-CVE-2014-6591
%patch10 -p3 -b .CVE-2014-8146
%patch11 -p3 -b .CVE-2014-8147
%patch12 -p3 -b .overflow
%patch13 -p1 -b .ucnv_name
%patch14 -p1 -b .CVE-2015-4760

mkdir -p docs
pushd docs
	unzip -q %{SOURCE1}
popd

%build
pushd source
%configure2_5x \
	--with-library-bits=64else32 \
	--with-data-packaging=archive \
	--disable-renaming \
	--disable-samples
%make
%make doc
popd

%install
%makeinstall_std -C source
%multiarch_binaries %{buildroot}%{_bindir}/icu-config

%files
%{_bindir}/*
%exclude %{_bindir}/icu-config
%exclude %{multiarch_bindir}
%{_sbindir}/*

%files -n %{dataname}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/icudt%{major}l.dat

%files doc
%doc readme.html docs/*
%{_mandir}/man1/*
%{_mandir}/man8/*

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%{_bindir}/icu-config
%{multiarch_bindir}/icu-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/layout
%dir %{_includedir}/unicode
%{_includedir}/layout/*
%{_includedir}/unicode/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/current
%{_libdir}/%{name}/pkgdata.inc
%{_datadir}/%{name}/%{version}/config
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/license.html
%{_datadir}/%{name}/%{version}/mkinstalldirs


%changelog
* Wed Jul 29 2015 luigiwalser <luigiwalser> 1:53.1-12.2.mga5
+ Revision: 858775
- add patch from debian to fix CVE-2015-4760
- add patch from chromium to fix CVE-2015-1270 (cjw)

* Tue May 05 2015 luigiwalser <luigiwalser> 1:53.1-12.mga5
+ Revision: 821270
- add upstream patches to fix CVE-2014-814[67] and an integer overflow

* Thu Mar 05 2015 luigiwalser <luigiwalser> 1:53.1-11.mga5
+ Revision: 817819
- add upstream patch to fix CVE-2014-6585 and CVE-2014-6591

* Wed Jan 28 2015 luigiwalser <luigiwalser> 1:53.1-10.mga5
+ Revision: 812587
- add another upstream change related to security issues fixed in chromium

* Tue Jan 27 2015 luigiwalser <luigiwalser> 1:53.1-9.mga5
+ Revision: 812572
- add upstream changes to fix CVE-2014-7923 and CVE-2014-7926

* Wed Nov 26 2014 cjw <cjw> 1:53.1-8.mga5
+ Revision: 799325
- remove duplicate entry in file list of icu package

* Wed Nov 26 2014 cjw <cjw> 1:53.1-7.mga5
+ Revision: 799317
- make icu-config a multiarch binary (mga#13538)

* Wed Oct 15 2014 umeabot <umeabot> 1:53.1-6.mga5
+ Revision: 739067
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:53.1-5.mga5
+ Revision: 680456
- Mageia 5 Mass Rebuild

* Sun Apr 06 2014 wally <wally> 1:53.1-4.mga5
+ Revision: 612440
- remove icu-data obsoletes now when it's removed from mirrors

* Sun Apr 06 2014 wally <wally> 1:53.1-3.mga5
+ Revision: 612250
- add major to data pkg name to allow multiple ones being installed simultaneously

* Sat Apr 05 2014 wally <wally> 1:53.1-2.mga5
+ Revision: 611792
- loosen lib pkg requires to not defeat the purpose of libification on lib major changes

* Fri Apr 04 2014 fwang <fwang> 1:53.1-1.mga5
+ Revision: 611718
- 53.1

* Mon Oct 21 2013 umeabot <umeabot> 1:52.1-2.mga4
+ Revision: 540925
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 fwang <fwang> 1:52.1-1.mga4
+ Revision: 494532
- disable check
- update file list
- update file list
- 52.1

* Thu Sep 26 2013 fwang <fwang> 1:52-0.rc2.1.mga4
+ Revision: 486755
- update file list
- new version 52rc2
- strict versioned requires

* Sun May 26 2013 fwang <fwang> 1:51.2-2.mga4
+ Revision: 427922
- tighten req

* Sun May 26 2013 fwang <fwang> 1:51.2-1.mga4
+ Revision: 427906
- new version 51.2

* Thu May 23 2013 fwang <fwang> 1:51.1-1.mga4
+ Revision: 424705
- new version 51.1

* Wed Jan 30 2013 luigiwalser <luigiwalser> 1:50.1.2-1.mga3
+ Revision: 393609
- 50.1.2

* Sat Jan 12 2013 umeabot <umeabot> 1:50.1.1-2.mga3
+ Revision: 354220
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 fwang <fwang> 1:50.1.1-1.mga3
+ Revision: 333784
- new version 50.1.1

* Sat Nov 10 2012 fwang <fwang> 1:50.1-5.mga3
+ Revision: 316795
- add upstream real fix

* Fri Nov 09 2012 fwang <fwang> 1:50.1-4.mga3
+ Revision: 316695
- add patch from upstream bug#9717 to disable cxx11

* Thu Nov 08 2012 fwang <fwang> 1:50.1-3.mga3
+ Revision: 316345
- split out data file
- disable renaming form uconfig as suggested

* Thu Nov 08 2012 fwang <fwang> 1:50.1-2.mga3
+ Revision: 316341
- update build switch as sugggested by upstream

* Tue Nov 06 2012 fwang <fwang> 1:50.1-1.mga3
+ Revision: 314716
- new version 50.1

* Fri Jun 08 2012 fwang <fwang> 1:49.1.2-1.mga3
+ Revision: 257499
- new version 49.1.2

* Tue May 29 2012 fwang <fwang> 1:49.1.1-1.mga3
+ Revision: 248933
- new version 49.1.1

* Fri Dec 30 2011 anssi <anssi> 1:4.8.1.1-2.mga2
+ Revision: 188944
- fix CVE-2011-4599 (buffer overflow, patch from rhel6, via Mandriva)

* Sun Nov 27 2011 fwang <fwang> 1:4.8.1.1-1.mga2
+ Revision: 172772
- new version 4.8.1.1

* Fri Sep 02 2011 tv <tv> 1:4.8.1-2.mga2
+ Revision: 137820
- make the huge doc subpackage be noarch

  + fwang <fwang>
    - new version 4.8.1

* Mon Jun 20 2011 fwang <fwang> 1:4.8-1.mga2
+ Revision: 110250
- sync patches from mandriva
- new version 4.8

  + rtp <rtp>
    - backport fix from upstream ticket 7664 (bad asm syntax)

* Sun Jan 09 2011 blino <blino> 1:4.4.2-2.mga1
+ Revision: 1505
- remove old ldconfig scriptlets
- imported package icu

